"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RCSFile = void 0;
const AbstractFileMessage_1 = require("../AbstractFileMessage");
const enums_1 = require("../../enums");
/**
 * Represents a file message for the RCS channel.
 *
 * @group RCS
 */
class RCSFile extends AbstractFileMessage_1.AbstractFileMessage {
    /**
     * Sends a file message to the RCS channel.
     *
     * @param {RCSFileParams} params - The parameters for creating a RCS file message.
     *
     * @example
     * ```ts
     * import { RCSFile } from '@vonage/messages';
     *
     * const { messageUUID } = await messagesClient.send(new RCSFile({
     *  to: TO_NUMBER,
     *  from: FROM_NUMBER,
     *  file: {
     *    url: 'https://example.com/image.pdf',
     *  },
     *  clientRef: 'my-personal-reference',
     * }));
     *
     * console.log(`Message sent successfully with UUID ${messageUUID}`);
     * ```
     */
    constructor(params) {
        super(params);
        /**
         * The channel for this message (always 'rcs').
         */
        this.channel = enums_1.Channels.RCS;
        this.ttl = params.ttl;
    }
}
exports.RCSFile = RCSFile;
