"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RCSImage = void 0;
const AbstractImageMessage_1 = require("../AbstractImageMessage");
const enums_1 = require("../../enums");
/**
 * Represents an image message for the RCS channel.
 *
 * @group RCS
 */
class RCSImage extends AbstractImageMessage_1.AbstractImageMessage {
    /**
     * Send an RCS image message.
     *
     * @param {RCSImageParams} params - The parameters for creating the image message.
     * @example
     * ```ts
     * import { RCSImage } from '@vonage/messages';
     *
     * const { messageUUID } = await messagesClient.send(new RCSImage({
     *  to: TO_NUMBER,
     *  from: FROM_NUMBER,
     *  image: {
     *    url: 'https://example.com/image.jpg',
     *  },
     *  clientRef: 'my-personal-reference',
     * }));
     *
     * console.log(`Message sent successfully with UUID ${messageUUID}`);
     * ```
     */
    constructor(params) {
        super(params);
        /**
         * The channel through which the message will be sent. Always `rcs`
         */
        this.channel = enums_1.Channels.RCS;
        this.ttl = params.ttl;
    }
}
exports.RCSImage = RCSImage;
